@@ -1,7 +1,7 @@
-from hayhooks.server.routers.status import router as status_router
-from hayhooks.server.routers.draw import router as draw_router
 from hayhooks.server.routers.deploy import router as deploy_router
-from hayhooks.server.routers.undeploy import router as undeploy_router
+from hayhooks.server.routers.draw import router as draw_router
 from hayhooks.server.routers.openai import router as openai_router
+from hayhooks.server.routers.status import router as status_router
+from hayhooks.server.routers.undeploy import router as undeploy_router
 
-__all__ = ['status_router', 'draw_router', 'deploy_router', 'undeploy_router', 'openai_router']
+__all__ = ["deploy_router", "draw_router", "openai_router", "status_router", "undeploy_router"]
