@@ -1,7 +1,10 @@
+from collections.abc import Generator
 from pathlib import Path
-from typing import Generator, List, Union
+from typing import Union
+
 from haystack import Pipeline
-from hayhooks import get_last_user_message, BasePipelineWrapper, log
+
+from hayhooks import BasePipelineWrapper, get_last_user_message, log
 
 
 class PipelineWrapper(BasePipelineWrapper):
@@ -9,13 +12,13 @@ class PipelineWrapper(BasePipelineWrapper):
         pipeline_yaml = (Path(__file__).parent / "chat_with_website.yml").read_text()
         self.pipeline = Pipeline.loads(pipeline_yaml)
 
-    def run_api(self, urls: List[str], question: str) -> str:
+    def run_api(self, urls: list[str], question: str) -> str:
         log.trace(f"Running pipeline with urls: {urls} and question: {question}")
 
         # NOTE: This is used in tests, please don't change it
         return "This is a mock response from the pipeline"
 
-    def run_chat_completion(self, model: str, messages: List[dict], body: dict) -> Union[str, Generator]:
+    def run_chat_completion(self, model: str, messages: list[dict], body: dict) -> Union[str, Generator]:
         log.trace(f"Running pipeline with model: {model}, messages: {messages}, body: {body}")
 
         question = get_last_user_message(messages)
