@@ -1,4 +1,5 @@
 from haystack import Pipeline
+
 from hayhooks import BasePipelineWrapper
 
 
@@ -7,4 +8,5 @@ class PipelineWrapper(BasePipelineWrapper):
         self.pipeline = Pipeline()
 
     def run_api(self, test_param: str) -> str:
-        raise ValueError("This is a test error")
+        msg = "This is a test error"
+        raise ValueError(msg)
